#
# spec file for package certmonger
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2020 Stasiek Michalski <stasiek@michalski.cc>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           certmonger
Version:        0.79.15
Release:        2.1
Summary:        Certificate status monitor and PKI enrollment client
License:        GPL-3.0-or-later

URL:            http://pagure.io/certmonger/
Source0:        http://releases.pagure.org/certmonger/certmonger-%{version}.tar.gz
Patch0001:      0001-Disable-DSA-in-the-RPM-spec.patch

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  dbus-1
BuildRequires:  dbus-1-devel
BuildRequires:  dbus-1-daemon
BuildRequires:  diffutils
BuildRequires:  dos2unix
BuildRequires:  expect
BuildRequires:  gcc
BuildRequires:  gettext-devel
BuildRequires:  krb5-devel
BuildRequires:  libcurl-devel
BuildRequires:  libfreebl3-hmac
BuildRequires:  libidn2-devel
BuildRequires:  libjansson-devel >= 2.12
BuildRequires:  libsoftokn3-hmac
BuildRequires:  libtalloc-devel
BuildRequires:  libtevent-devel
BuildRequires:  libuuid-devel
BuildRequires:  libxml2-devel
BuildRequires:  mozilla-nspr-devel
BuildRequires:  mozilla-nss-devel
BuildRequires:  mozilla-nss-sysinit
BuildRequires:  mozilla-nss-tools
BuildRequires:  openldap2-devel
BuildRequires:  openssl
BuildRequires:  openssl-devel
BuildRequires:  popt-devel
BuildRequires:  python3-dbus-python
# Note - this is required for /usr/share/pkgconfig/systemd.pc, which is used by
# --enable-systemd to discover the unitfile location. There is no way to inject
# this location via the configure call either.
## Note: using pkgconfig(systemd) BR to allow hacksaw systemd-mini package to
## satisfy in the openSUSE Build Service
BuildRequires:  pkgconfig(systemd)
BuildRequires:  which
BuildRequires:  xmlrpc-c-devel

Requires:       dbus-1
Requires(post): dbus-1
Requires(preun):dbus-1
Requires(preun):sed

BuildRequires:  systemd-rpm-macros
%{?systemd_requires}

%description
Certmonger is a service which is primarily concerned with getting your
system enrolled with a certificate authority (CA) and keeping it enrolled.

%prep
%autosetup -p1

%build
autoreconf -i -f
%configure \
    --enable-systemd \
    --enable-tmpfiles \
    --disable-dsa \
    --with-homedir=/run/certmonger \
    --with-tmpdir=/run/certmonger --enable-pie --enable-now

%make_build

%install
%make_install
mkdir -p %{buildroot}/%{_localstatedir}/lib/certmonger/{cas,requests}
%{find_lang} %{name}

%check
make check

%pre
%service_add_pre certmonger.service

%post
if test $1 -eq 1 ; then
  %{_bindir}/dbus-send --system --type=method_call --dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig 2>&1 || :
fi
%service_add_post certmonger.service
%tmpfiles_create certmonger.conf

%preun
%service_del_preun certmonger.service

%postun
%service_del_postun certmonger.service

%files -f %{name}.lang
%doc README.md LICENSE STATUS doc/*.txt
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/*
%{_datadir}/dbus-1/services/*
%dir %{_sysconfdir}/certmonger
%config(noreplace) %{_sysconfdir}/certmonger/certmonger.conf
%ghost /run/certmonger
%{_bindir}/*
%{_sbindir}/certmonger
%{_mandir}/man*/*
%{_libexecdir}/%{name}
%{_localstatedir}/lib/certmonger
%{_unitdir}/certmonger.service
%{_tmpfilesdir}/certmonger.conf
%{_datadir}/dbus-1/system-services/*

%changelog
* Wed Oct 11 2023 Simon Lees <sflees@suse.de>
- dbus-daemon is now split out into a separate package.
* Fri Jun 17 2022 Matthew Davis <novell@virtual.drop.net>
- Added 0001-Disable-DSA-in-the-RPM-spec.patch
- Removed 0002-certmonger-return-type.patch.
* Fri Jun 17 2022 Matthew Davis <novell@virtual.drop.net>
- Updated to version 0.79.15
- Added minimum libjansson version requirement.
* Mon Jul 26 2021 Neal Gompa <ngompa13@gmail.com>
- Use "pkgconfig(systemd)" for the BR to allow hacksaw systemd-mini
  package to satisfy dependencies in the openSUSE Build Service.
* Mon Jul 26 2021 William Brown <william.brown@suse.com>
- Add buildrequires on systemd which is required for correct installation
  of the .service file.
* Sun Feb 28 2021 Sasi Olin <hel@lcp.world>
- Update to 0.79.13
* Mon Aug 31 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.79.11:
  - Fix crash bug when generating thumbprints
  - dogtag: use POST for profileProcess requests
  - Improve logging in SCEP helper
  - Add verbose option to SCEP CA if requested in add-scep-ca
  - Re-order the way the SCEP signing and CA certs are collected
  - Add new option to allow overriding the detected SCEP CA chain
  - template_profile, issuer and MS certificate template are single-value
  - Ensure that files read in have a trailing new-line
  - Adapt to the new behavior of disconnect in dbus-broker
  - Add long command-line options to CLI and man pages
  - Include &message=CA-IDENT with GetCACaps and GetCACert requests
  - Address issues uncovered by clang and Coverity
  - Handle an uninitialized token when adding CA certs to an NSS db
  - tests: Parametrize 025-casave with NSS db types
* Sun Apr 12 2020 Stasiek Michalski <stasiek@michalski.cc>
- Initial package
